diff --git a/types/openlayers/index.d.ts b/types/openlayers/index.d.ts
index d149ef18bc..f2eb6a8b53 100644
--- a/types/openlayers/index.d.ts
+++ b/types/openlayers/index.d.ts
@@ -1830,11 +1830,11 @@ declare module ol {
* Get the feature's style. This return for this method depends on what was
* provided to the {@link ol.Feature#setStyle} method.
* @return {ol.style.Style|Array.
|
* ol.FeatureStyleFunction} The feature style.
* @api stable
* @observable
*/
- getStyle(): (ol.style.Style | ol.style.Style[] | ol.FeatureStyleFunction);
+ getStyle(): (ol.style.Style | ol.style.Style[] | ol.FeatureStyleFunction | ol.StyleFunction);
/**
* Get the feature's style function.
@@ -1858,11 +1858,11 @@ declare module ol {
* of styles, or a function that takes a resolution and returns an array of
* styles. If it is `null` the feature has no style (a `null` style).
* @param {ol.style.Style|Array.|
* ol.FeatureStyleFunction} style Style for this feature.
* @api stable
* @observable
*/
- setStyle(style: (ol.style.Style | ol.style.Style[] | ol.FeatureStyleFunction)): void;
+ setStyle(style: (ol.style.Style | ol.style.Style[] | ol.FeatureStyleFunction | ol.StyleFunction)): void;
/**
* Set the feature id. The feature id is considered stable and may be used when
@@ -10590,7 +10590,7 @@ declare module ol {
* @api
*/
clone(): ol.style.Style;
-
+
/**
* Get the geometry to be rendered.
* @return {string|ol.geom.Geometry|ol.StyleGeometryFunction}
@@ -1830,11 +1830,11 @@ declare module ol {
* @return {ol.style.Style|Array.
|
- * ol.FeatureStyleFunction} The feature style.
+ * ol.FeatureStyleFunction|ol.StyleFunction} The feature style.
* @api stable
* @observable
@@ -1858,11 +1858,11 @@ declare module ol {
* styles. If it is `null` the feature has no style (a `null` style).
* @param {ol.style.Style|Array.|
- * ol.FeatureStyleFunction} style Style for this feature.
+ * ol.FeatureStyleFunction|ol.StyleFunction} style Style for this feature.
* @api stable
* @observable